@@ -1,4 +1,4 @@
-use crate::units::Units;
+use crate::{location::client::LocationProvider, units::Units};
 
 #[derive(Clone, Debug)]
 pub struct Options {
@@ -6,6 +6,7 @@ pub struct Options {
     pub connect_timeout: Option<u64>,
     pub timeout: Option<u64>,
     pub query: Option<String>,
+    pub location_provider: Option<LocationProvider>,
     pub full_info: Option<bool>,
     pub silent: Option<bool>,
     pub version: Option<String>,
